@@ -62,9 +62,6 @@ Database::Database(QObject *parent) :
     if (database.open()) {
         database.exec("CREATE TABLE IF NOT EXISTS stations (id TEXT UNIQUE, title TEXT, description TEXT, logo TEXT, genre TEXT, country TEXT, language TEXT, source TEXT, favourite INTEGER, lastPlayed TEXT)");
         database.exec("CREATE TABLE IF NOT EXISTS podcasts (id TEXT UNIQUE, title TEXT, description TEXT, logo TEXT, source TEXT, service INTEGER)");
-        database.exec("CREATE TABLE IF NOT EXISTS genres (name TEXT UNIQUE, stationCount INTEGER)");
-        database.exec("CREATE TABLE IF NOT EXISTS countries (name TEXT UNIQUE, stationCount INTEGER)");
-        database.exec("CREATE TABLE IF NOT EXISTS languages (name TEXT UNIQUE, stationCount INTEGER)");
     }
     else {
         qWarning() << "Cannot open database:" << database.lastError().text();
@@ -110,10 +107,6 @@ bool Database::addStation(const QString &title,
     query.addBindValue(0);
 
     if (query.exec()) {
-        this->addGenre(genre);
-        this->addCountry(country);
-        this->addLanguage(language);
-
         emit stationAdded();
         emit alert(QString("%1 '%2' %3").arg(tr("New station")).arg(title).arg(tr("added")));
 
@@ -131,28 +124,6 @@ bool Database::updateStation(const QString &id, const QVariantMap &properties, b
     }
 
     QSqlQuery query;
-    QString oldGenre;
-    QString oldCountry;
-    QString oldLanguage;
-
-    if ((properties.contains("genre")) || (properties.contains("country")) || (properties.contains("language"))) {
-        query.prepare("SELECT genre, country, language FROM stations WHERE id = ?");
-        query.addBindValue(id);
-
-        if (query.exec()) {
-
-            QSqlRecord record = query.record();
-
-            if (record.count()) {
-                while (query.next()) {
-                    oldGenre = query.value(0).toString();
-                    oldCountry = query.value(1).toString();
-                    oldLanguage = query.value(2).toString();
-                }
-            }
-        }
-    }
-
     QString queryString("UPDATE stations SET ");
     QMapIterator<QString, QVariant>iterator(properties);
 
@@ -166,19 +137,6 @@ bool Database::updateStation(const QString &id, const QVariantMap &properties, b
     queryString.append("WHERE id = " + id);
 
     if (query.exec(queryString)) {
-        if (properties.contains("genre")) {
-            this->updateGenreStationCount(oldGenre);
-            this->addGenre(properties.value("genre").toString());
-        }
-        if (properties.contains("country")) {
-            this->updateCountryStationCount(oldCountry);
-            this->addCountry(properties.value("country").toString());
-        }
-        if (properties.contains("language")) {
-            this->updateLanguageStationCount(oldLanguage);
-            this->addLanguage(properties.value("language").toString());
-        }
-
         emit stationUpdated(id, properties);
 
         if (notify) {
@@ -201,43 +159,11 @@ bool Database::updateStation(const QString &id, const QString &property, const Q
     }
 
     QSqlQuery query;
-    QString oldValue;
-
-    if ((property == "genre") || (property == "country") || (property == "language")) {
-        query.prepare("SELECT ? FROM stations WHERE id = ?");
-        query.addBindValue(property);
-        query.addBindValue(id);
-
-        if (query.exec()) {
-
-            QSqlRecord record = query.record();
-
-            if (record.count()) {
-                while (query.next()) {
-                    oldValue = query.value(0).toString();
-                }
-            }
-        }
-    }
-
     query.prepare(QString("UPDATE stations SET %1 = ? WHERE id = ?").arg(property));
     query.addBindValue(value);
     query.addBindValue(id);
 
     if (query.exec()) {
-        if (property == "genre") {
-            this->updateGenreStationCount(oldValue);
-            this->addGenre(value.toString());
-        }
-        else if (property == "country") {
-            this->updateCountryStationCount(oldValue);
-            this->addCountry(value.toString());
-        }
-        else if (property == "language") {
-            this->updateLanguageStationCount(oldValue);
-            this->addLanguage(value.toString());
-        }
-
         emit stationUpdated(id, property, value);
 
         if (notify) {
@@ -260,40 +186,14 @@ bool Database::deleteStation(const QString &id) const {
     }
 
     QSqlQuery query;
-    query.prepare("SELECT genre, country, language FROM stations WHERE id = ?");
+    query.prepare("DELETE FROM stations WHERE id = ?");
     query.addBindValue(id);
 
     if (query.exec()) {
-        QString genre;
-        QString country;
-        QString language;
-        QSqlRecord record = query.record();
+        emit stationDeleted(id);
+        emit alert(tr("Station deleted"));
 
-        if (record.count()) {
-            while (query.next()) {
-                genre = query.value(0).toString();
-                country = query.value(1).toString();
-                language = query.value(2).toString();
-            }
-        }
-
-        query.prepare("DELETE FROM stations WHERE id = ?");
-        query.addBindValue(id);
-
-        if (query.exec()) {
-            this->updateGenreStationCount(genre);
-            this->updateCountryStationCount(country);
-            this->updateLanguageStationCount(language);
-
-            emit stationDeleted(id);
-            emit alert(tr("Station deleted"));
-
-            return true;
-        }
-
-        emit error(tr("Cannot delete station"));
-
-        return false;
+        return true;
     }
 
     emit error(tr("Cannot delete station"));
@@ -335,263 +235,38 @@ bool Database::asyncDeleteStation(const QString &id) {
     return QMetaObject::invokeMethod(Database::instance(), "deleteStation", Qt::QueuedConnection, Q_ARG(QString, id));
 }
 
-bool Database::addGenre(const QString &genre) const {
-    if (!QSqlDatabase::database().open()) {
-        return false;
-    }
-
-    QSqlQuery query;
-    int count = this->getStationCount("genre", genre);
-
-    if (count == 1) {
-        query.prepare("INSERT INTO genres VALUES (?, ?)");
-        query.addBindValue(genre);
-        query.addBindValue(count);
-
-        if (query.exec()) {
-            emit genreAdded(genre, count);
-
-            return true;
-        }
-
-        return false;
-    }
-    else {
-        query.prepare("UPDATE genres SET stationCount = ? WHERE name = ?");
-        query.addBindValue(count);
-        query.addBindValue(genre);
-
-        if (query.exec()) {
-            emit genreUpdated(genre, count);
-
-            return true;
-        }
-
-        return false;
-    }
-}
-
-bool Database::updateGenreStationCount(const QString &genre) const {
-    int count = this->getStationCount("genre", genre);
-
-    if (!count) {
-        return this->deleteGenre(genre);
-    }
-
-    if (!QSqlDatabase::database().open()) {
-        return false;
-    }
-
-    QSqlQuery query;
-    query.prepare("UPDATE genres SET stationCount = ? WHERE name = ?");
-    query.addBindValue(count);
-    query.addBindValue(genre);
-
-    if (query.exec()) {
-        emit genreUpdated(genre, count);
-
-        return true;
-    }
-
-    return false;
-}
-
-bool Database::deleteGenre(const QString &genre) const {
-    if (!QSqlDatabase::database().open()) {
-        return false;
-    }
-
-    QSqlQuery query;
-    query.prepare("DELETE FROM genres WHERE name = ?");
-    query.addBindValue(genre);
-
-    if (query.exec()) {
-        emit genreDeleted(genre);
-
-        return true;
-    }
-
-    return false;
-}
-
-bool Database::addCountry(const QString &country) const {
-    if (!QSqlDatabase::database().open()) {
-        return false;
-    }
-
-    QSqlQuery query;
-    int count = this->getStationCount("country", country);
-
-    if (count == 1) {
-        query.prepare("INSERT INTO countries VALUES (?, ?)");
-        query.addBindValue(country);
-        query.addBindValue(count);
-
-        if (query.exec()) {
-            emit countryAdded(country, count);
-
-            return true;
-        }
-
-        return false;
-    }
-    else {
-        query.prepare("UPDATE countries SET stationCount = ? WHERE name = ?");
-        query.addBindValue(count);
-        query.addBindValue(country);
-
-        if (query.exec()) {
-            emit countryUpdated(country, count);
-
-            return true;
-        }
-
-        return false;
-    }
-}
-
-bool Database::updateCountryStationCount(const QString &country) const {
-    int count = this->getStationCount("country", country);
-
-    if (!count) {
-        return this->deleteCountry(country);
-    }
-
-    if (!QSqlDatabase::database().open()) {
-        return false;
-    }
-
-    QSqlQuery query;
-    query.prepare("UPDATE countries SET stationCount = ? WHERE name = ?");
-    query.addBindValue(count);
-    query.addBindValue(country);
-
-    if (query.exec()) {
-        emit countryUpdated(country, count);
-
-        return true;
-    }
-
-    return false;
-}
-
-bool Database::deleteCountry(const QString &country) const {
-    if (!QSqlDatabase::database().open()) {
-        return false;
-    }
-
-    QSqlQuery query;
-    query.prepare("DELETE FROM countries WHERE name = ?");
-    query.addBindValue(country);
-
-    if (query.exec()) {
-        emit countryDeleted(country);
-
-        return true;
-    }
-
-    return false;
-}
-
-bool Database::addLanguage(const QString &language) const {
-    if (!QSqlDatabase::database().open()) {
-        return false;
-    }
-
-    QSqlQuery query;
-    int count = this->getStationCount("language", language);
-
-    if (count == 1) {
-        query.prepare("INSERT INTO languages VALUES (?, ?)");
-        query.addBindValue(language);
-        query.addBindValue(count);
-
-        if (query.exec()) {
-            emit languageAdded(language, count);
-
-            return true;
-        }
-
-        return false;
-    }
-    else {
-        query.prepare("UPDATE languages SET stationCount = ? WHERE name = ?");
-        query.addBindValue(count);
-        query.addBindValue(language);
-
-        if (query.exec()) {
-            emit languageUpdated(language, count);
-
-            return true;
-        }
-
-        return false;
-    }
-}
-
-bool Database::updateLanguageStationCount(const QString &language) const {
-    int count = this->getStationCount("language", language);
-
-    if (!count) {
-        return this->deleteLanguage(language);
-    }
-
-    if (!QSqlDatabase::database().open()) {
-        return false;
-    }
-
-    QSqlQuery query;
-    query.prepare("UPDATE languages SET stationCount = ? WHERE name = ?");
-    query.addBindValue(count);
-    query.addBindValue(language);
-
-    if (query.exec()) {
-        emit languageUpdated(language, count);
-
-        return true;
-    }
-
-    return false;
-}
-
-bool Database::deleteLanguage(const QString &language) const {
-    if (!QSqlDatabase::database().open()) {
-        return false;
-    }
-
-    QSqlQuery query;
-    query.prepare("DELETE FROM langauges WHERE name = ?");
-    query.addBindValue(language);
-
-    if (query.exec()) {
-        emit languageDeleted(language);
-
-        return true;
-    }
-
-    return false;
-}
-
-int Database::getStationCount(const QString &property, const QVariant &value) const {
-    int count = 0;
+QList<Station*> Database::getStations() const {
+    QList<Station*> stations;
 
     if (QSqlDatabase::database().open()) {
         QSqlQuery query;
-        query.prepare(QString("SELECT COUNT (*) FROM stations WHERE %1 = ?").arg(property));
-        query.addBindValue(value);
+        query.prepare("SELECT * FROM stations ORDER BY title ASC");
 
         if (query.exec()) {
             QSqlRecord record = query.record();
 
             if (record.count()) {
                 while (query.next()) {
-                    count = query.value(0).toInt();
+                    Station *station = new Station(Stations::Radio,
+                                                   Services::NoService,
+                                                   query.value(0).toString(),
+                                                   query.value(1).toString(),
+                                                   query.value(2).toString(),
+                                                   QUrl::fromLocalFile(query.value(3).toString()),
+                                                   query.value(4).toString(),
+                                                   query.value(5).toString(),
+                                                   query.value(6).toString(),
+                                                   query.value(7).toUrl(),
+                                                   query.value(8).toBool(),
+                                                   query.value(9).toLongLong());
+
+                    stations.append(station);
                 }
             }
         }
     }
 
-    return count;
+    return stations;
 }
 
 QList<Station*> Database::getRecentlyPlayedStations() const {
@@ -838,6 +513,10 @@ QList<Station*> Database::getStationsByLanguage(const QString &language) const {
     return stations;
 }
 
+void Database::asyncGetStations() const {
+    emit gotStations(this->getStations());
+}
+
 void Database::asyncGetRecentlyPlayedStations() const {
     emit gotStations(this->getRecentlyPlayedStations());
 }
@@ -866,78 +545,6 @@ void Database::asyncGetStationsByLanguage(const QString &language) const {
     emit gotStations(this->getStationsByLanguage(language));
 }
 
-QList< QPair<QString, int> > Database::getGenres() const {
-    QList< QPair<QString, int> > genres;
-
-    if (QSqlDatabase::database().open()) {
-        QSqlQuery query;
-
-        if (query.exec("SELECT * FROM genres ORDER BY name ASC")) {
-            QSqlRecord record = query.record();
-
-            if (record.count()) {
-                while (query.next()) {
-                    genres.append(QPair<QString, int>(query.value(0).toString(), query.value(1).toInt()));
-                }
-            }
-        }
-    }
-
-    return genres;
-}
-
-QList< QPair<QString, int> > Database::getCountries() const {
-    QList< QPair<QString, int> > countries;
-
-    if (QSqlDatabase::database().open()) {
-        QSqlQuery query;
-
-        if (query.exec("SELECT * FROM countries ORDER BY name ASC")) {
-            QSqlRecord record = query.record();
-
-            if (record.count()) {
-                while (query.next()) {
-                    countries.append(QPair<QString, int>(query.value(0).toString(), query.value(1).toInt()));
-                }
-            }
-        }
-    }
-
-    return countries;
-}
-
-QList< QPair<QString, int> > Database::getLanguages() const {
-    QList< QPair<QString, int> > languages;
-
-    if (QSqlDatabase::database().open()) {
-        QSqlQuery query;
-
-        if (query.exec("SELECT * FROM languages ORDER BY name ASC")) {
-            QSqlRecord record = query.record();
-
-            if (record.count()) {
-                while (query.next()) {
-                    languages.append(QPair<QString, int>(query.value(0).toString(), query.value(1).toInt()));
-                }
-            }
-        }
-    }
-
-    return languages;
-}
-
-void Database::asyncGetGenres() const {
-    emit gotGenres(this->getGenres());
-}
-
-void Database::asyncGetCountries() const {
-    emit gotCountries(this->getCountries());
-}
-
-void Database::asyncGetLanguages() const {
-    emit gotLanguages(this->getLanguages());
-}
-
 // Podcasts
 bool Database::addPodcast(const QString &title,
                           const QString &description,
