@@ -58,6 +58,7 @@ public slots:
     static bool asyncUpdateStation(const QString &id, const QString &property, const QVariant &value, bool notify = true);
     static bool asyncDeleteStation(const QString &id);
 
+    QList<Station*> getStations() const;
     QList<Station*> getRecentlyPlayedStations() const;
     QList<Station*> getFavouriteStations() const;
     QList<Station*> getStationsById(const QStringList &ids) const;
@@ -66,6 +67,7 @@ public slots:
     QList<Station*> getStationsByCountry(const QString &country) const;
     QList<Station*> getStationsByLanguage(const QString &language) const;
 
+    void asyncGetStations() const;
     void asyncGetRecentlyPlayedStations() const;
     void asyncGetFavouriteStations() const;
     void asyncGetStationsById(const QStringList &ids) const;
@@ -74,14 +76,6 @@ public slots:
     void asyncGetStationsByCountry(const QString &country) const;
     void asyncGetStationsByLanguage(const QString &language) const;
 
-    QList< QPair<QString, int> > getGenres() const;
-    QList< QPair<QString, int> > getCountries() const;
-    QList< QPair<QString, int> > getLanguages() const;
-
-    void asyncGetGenres() const;
-    void asyncGetCountries() const;
-    void asyncGetLanguages() const;
-
     // Podcasts
     bool addPodcast(const QString &title,
                     const QString &description,
@@ -109,49 +103,18 @@ public slots:
     void asyncGetPodcastsById(const QStringList &ids) const;
     void asyncGetPodcastsByTitle(const QString &title) const;
 
-private:
-    // Stations
-    bool addGenre(const QString &genre) const;
-    bool updateGenreStationCount(const QString &genre) const;
-    bool deleteGenre(const QString &genre) const;
-
-    bool addCountry(const QString &country) const;
-    bool updateCountryStationCount(const QString &country) const;
-    bool deleteCountry(const QString &country) const;
-
-    bool addLanguage(const QString &language) const;
-    bool updateLanguageStationCount(const QString &language) const;
-    bool deleteLanguage(const QString &language) const;
-
-    int getStationCount(const QString &property, const QVariant &value) const;
-
 signals:
     void alert(const QString &message) const;
     void error(const QString &errorString) const;
 
     // Stations
     void gotStations(const QList<Station*> &stations) const;
-    void gotGenres(const QList< QPair<QString, int> > &genres) const;
-    void gotCountries(const QList< QPair<QString, int> > &countries) const;
-    void gotLanguages(const QList< QPair<QString, int> > &languages) const;
 
     void stationAdded() const;
     void stationUpdated(const QString &id, const QVariantMap &properties) const;
     void stationUpdated(const QString &id, const QString &property, const QVariant &value) const;
     void stationDeleted(const QString &id) const;
 
-    void genreAdded(const QString &name, int stationCount) const;
-    void genreUpdated(const QString &genre, int stationCount) const;
-    void genreDeleted(const QString &genre) const;
-
-    void countryAdded(const QString &name, int stationCount) const;
-    void countryUpdated(const QString &country, int stationCount) const;
-    void countryDeleted(const QString &country) const;
-
-    void languageAdded(const QString &name, int stationCount) const;
-    void languageUpdated(const QString &language, int stationCount) const;
-    void languageDeleted(const QString &language) const;
-
     // Podcasts
     void gotPodcasts(const QList<Station*> &podcasts) const;
 
