@@ -19,9 +19,7 @@
 
 HomescreenModel::HomescreenModel(QObject *parent) :
     QStringListModel(QStringList()
-                     << tr("Stations by genre")
-                     << tr("Stations by country")
-                     << tr("Stations by language")
+                     << tr("All stations")
                      << tr("Recently played stations")
                      << tr("Favourite stations")
 #ifdef TUNE_IN
