@@ -3,13 +3,23 @@
 #include "networkaccessmanager.h"
 #include "settings.h"
 
+NetworkAccessManager* NetworkAccessManager::self = 0;
+
 NetworkAccessManager::NetworkAccessManager(QObject *parent) :
     QNetworkAccessManager(parent)
 {
+    if (!self) {
+        self = this;
+    }
+
     this->connect(this, SIGNAL(sslErrors(QNetworkReply*,QList<QSslError>)), this, SLOT(onSSLErrors(QNetworkReply*,QList<QSslError>)));
     this->connect(this, SIGNAL(proxyAuthenticationRequired(QNetworkProxy,QAuthenticator*)), this, SLOT(onProxyAuthenticationRequired(QNetworkProxy,QAuthenticator*)));
 }
 
+NetworkAccessManager* NetworkAccessManager::instance() {
+    return !self ? new NetworkAccessManager : self;
+}
+
 void NetworkAccessManager::onSSLErrors(QNetworkReply *reply, const QList<QSslError> &errors) {
     reply->ignoreSslErrors(errors);
 }
