@@ -147,6 +147,10 @@ void StationFilterListModel::searchStations(const QString &query) {
     m_model->searchStations(query);
 }
 
+void StationFilterListModel::showStations() {
+    m_model->showStations();
+}
+
 void StationFilterListModel::showRecentlyPlayedStations() {
     m_model->showRecentlyPlayedStations();
 }
