@@ -171,6 +171,13 @@ void StationListModel::searchStations(const QString &query) {
     QMetaObject::invokeMethod(Database::instance(), "asyncGetStationsByTitle", Qt::QueuedConnection, Q_ARG(QString, query));
 }
 
+void StationListModel::showStations() {
+    this->setLoading(true);
+    this->setQueryType(Queries::Unknown);
+    this->connect(Database::instance(), SIGNAL(gotStations(QList<Station*>)), this, SLOT(addStations(QList<Station*>)));
+    QMetaObject::invokeMethod(Database::instance(), "asyncGetStations", Qt::QueuedConnection);
+}
+
 void StationListModel::showRecentlyPlayedStations() {
     this->setLoading(true);
     this->setQueryType(Queries::RecentlyPlayedStations);
@@ -239,6 +246,7 @@ void StationListModel::reload() {
         this->showStationsByLanguage(this->searchQuery());
         return;
     default:
+        this->showStations();
         return;
     }
 }
