@@ -31,7 +31,7 @@ public:
 
 protected slots:
     void onOrientationChanged();
-    void toggleBusy(bool busy);
+    virtual void toggleBusy(bool busy);
 
 protected:
     inline virtual void setLandscapeLayout() {}
