@@ -42,8 +42,10 @@ private:
     void setPortraitLayout();
     
 private slots:
-    void onTitleChanged(const QString &title);
-    void onSourceChanged(const QString &source);
+    void toggleBusy(bool busy);
+
+    void onTitleChanged();
+    void onSourceChanged();
 
     void addStation();
     void editStation();
