@@ -24,7 +24,6 @@
 #include "mainwindow.h"
 #include "listview.h"
 #include "homescreenlistdelegate.h"
-#include "browselistwindow.h"
 #include "stationlistwindow.h"
 #include "podcastlistwindow.h"
 #include "tuneinwindow.h"
@@ -100,24 +99,18 @@ MainWindow::MainWindow(QWidget *parent) :
 void MainWindow::onItemClicked(const QModelIndex &index) {
     switch (index.row()) {
     case 0:
-        this->showGenres();
+        this->showStations();
         return;
     case 1:
-        this->showCountries();
-        return;
-    case 2:
-        this->showLanguages();
-        return;
-    case 3:
         this->showRecentlyPlayedStations();
         return;
-    case 4:
+    case 2:
         this->showFavouriteStations();
         return;
-    case 5:
+    case 3:
         this->showPodcasts();
         return;
-    case 6:
+    case 4:
         this->showTuneIn();
         return;
     default:
@@ -156,21 +149,9 @@ void MainWindow::searchPodcasts() {
     m_searchEdit->clear();
 }
 
-void MainWindow::showGenres() {
-    BrowseListWindow *window = new BrowseListWindow(this);
-    window->showGenres();
-    window->show();
-}
-
-void MainWindow::showCountries() {
-    BrowseListWindow *window = new BrowseListWindow(this);
-    window->showCountries();
-    window->show();
-}
-
-void MainWindow::showLanguages() {
-    BrowseListWindow *window = new BrowseListWindow(this);
-    window->showLanguages();
+void MainWindow::showStations() {
+    StationListWindow *window = new StationListWindow(this);
+    window->showStations();
     window->show();
 }
 
