@@ -45,9 +45,7 @@ private slots:
     void search();
     void searchStations();
     void searchPodcasts();
-    void showGenres();
-    void showCountries();
-    void showLanguages();
+    void showStations();
     void showRecentlyPlayedStations();
     void showFavouriteStations();
     void showPodcasts();
