@@ -25,7 +25,11 @@
 #include "windowstack.h"
 #include "screen.h"
 #include "../base/station.h"
+#ifdef MOBILITY_PLAYER
+#include "../mediaplayer/mobility/mediaplayer.h"
+#else
 #include "../mediaplayer/phonon/mediaplayer.h"
+#endif
 
 NowPlayingButton* NowPlayingButton::self = 0;
 
