@@ -176,16 +176,21 @@ void NowPlayingWindow::onCurrentStationChanged(Station *station) {
 }
 
 void NowPlayingWindow::onPlayButtonClicked() {
-    if (MediaPlayer::instance()->playing()) {
+    switch (MediaPlayer::instance()->state()) {
+    case MediaState::Stopped:
+    case MediaState::Paused:
+    case MediaState::Error:
+        MediaPlayer::instance()->play();
+        return;
+    default:
         if (MediaPlayer::instance()->duration() > 0) {
             MediaPlayer::instance()->pause();
         }
         else {
             MediaPlayer::instance()->stop();
         }
-    }
-    else {
-        MediaPlayer::instance()->play();
+
+        return;
     }
 }
 
@@ -208,12 +213,14 @@ void NowPlayingWindow::onPlaybackStateChanged(MediaState::State state) {
     m_statusLabel->setText(QString("%1: %2").arg(tr("Status")).arg(MediaPlayer::instance()->stateString()));
 
     switch (state) {
-    case MediaState::Playing:
-        m_playButton->setIcon(MediaPlayer::instance()->duration() > 0 ? QIcon("/etc/hildon/theme/mediaplayer/Pause.png")
-                                                          : QIcon("/etc/hildon/theme/mediaplayer/Stop.png"));
+    case MediaState::Stopped:
+    case MediaState::Paused:
+    case MediaState::Error:
+        m_playButton->setIcon(QIcon("/etc/hildon/theme/mediaplayer/Play.png"));
         return;
     default:
-        m_playButton->setIcon(QIcon("/etc/hildon/theme/mediaplayer/Play.png"));
+        m_playButton->setIcon(MediaPlayer::instance()->duration() > 0 ? QIcon("/etc/hildon/theme/mediaplayer/Pause.png")
+                                                          : QIcon("/etc/hildon/theme/mediaplayer/Stop.png"));
         return;
     }
 }
