@@ -37,7 +37,7 @@ private:
     void setPortraitLayout();
 
 private slots:
-    void onSourceChanged(const QString &source);
+    void onSourceChanged();
 
     void playStation();
 
