@@ -18,6 +18,7 @@
 #include <QLabel>
 #include <QDialogButtonBox>
 #include <QSpinBox>
+#include <QLineEdit>
 #include <QScrollArea>
 #include <QGridLayout>
 #include "settingsdialog.h"
@@ -30,6 +31,8 @@ SettingsDialog::SettingsDialog(QWidget *parent) :
     AbstractDialog(parent),
     m_orientationSelector(new ValueSelector(tr("Screen orientation"), this)),
     m_languageSelector(new ValueSelector(tr("Language"), this)),
+    m_mediaPlayerSelector(new ValueSelector(tr("Media player"), this)),
+    m_mediaPlayerCommandEdit(new QLineEdit(this)),
     m_proxyButton(new QPushButton(tr("Network proxy"), this)),
     m_sleepTimerSpinBox(new QSpinBox(this)),
     m_buttonBox(new QDialogButtonBox(QDialogButtonBox::Save, Qt::Vertical, this)),
@@ -44,12 +47,17 @@ SettingsDialog::SettingsDialog(QWidget *parent) :
     vbox->setContentsMargins(0, 0, 0, 0);
     vbox->addWidget(m_languageSelector);
     vbox->addWidget(m_orientationSelector);
+    vbox->addWidget(m_mediaPlayerSelector);
+    vbox->addWidget(m_mediaPlayerCommandEdit);
     vbox->addWidget(m_proxyButton);
     vbox->addWidget(new QLabel(tr("Sleep timer duration (mins)")));
     vbox->addWidget(m_sleepTimerSpinBox);
 
     m_orientationSelector->setModel(new ScreenOrientationModel(m_orientationSelector));
     m_languageSelector->setModel(new LanguageModel(m_languageSelector));
+    m_mediaPlayerSelector->setModel(new MediaPlayerModel(m_mediaPlayerSelector));
+
+    m_mediaPlayerCommandEdit->setPlaceholderText(tr("Custom command"));
 
     m_sleepTimerSpinBox->setMaximum(999);
 
@@ -58,6 +66,7 @@ SettingsDialog::SettingsDialog(QWidget *parent) :
     m_scrollArea->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
     m_scrollArea->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Preferred);
 
+    this->connect(m_mediaPlayerSelector, SIGNAL(valueChanged(QVariant)), this, SLOT(onMediaPlayerChanged(QVariant)));
     this->connect(m_proxyButton, SIGNAL(clicked()), this, SLOT(showNetworkProxyDialog()));
     this->connect(m_buttonBox, SIGNAL(accepted()), this, SLOT(saveSettings()));
 
@@ -96,17 +105,29 @@ void SettingsDialog::setPortraitLayout() {
 void SettingsDialog::loadSettings() {
     m_languageSelector->setValue(Settings::instance()->language());
     m_orientationSelector->setValue(Settings::instance()->screenOrientation());
+    m_mediaPlayerSelector->setValue(Settings::instance()->mediaPlayer());
+    m_mediaPlayerCommandEdit->setText(Settings::instance()->mediaPlayerCommand());
+    m_mediaPlayerCommandEdit->setEnabled(Settings::instance()->mediaPlayer() == "other");
     m_sleepTimerSpinBox->setValue(Settings::instance()->sleepTimerDuration());
 }
 
 void SettingsDialog::saveSettings() {
     Settings::instance()->setLanguage(m_languageSelector->currentValue().toString());
     Settings::instance()->setScreenOrientation(static_cast<ScreenOrientation::Orientation>(m_orientationSelector->currentValue().toInt()));
+    Settings::instance()->setMediaPlayer((m_mediaPlayerSelector->currentValue().toString() == "other")
+                                         && (m_mediaPlayerCommandEdit->text().isEmpty())
+                                         ? "cuteradio"
+                                         : m_mediaPlayerSelector->currentValue().toString());
+    Settings::instance()->setMediaPlayerCommand(m_mediaPlayerCommandEdit->text());
     Settings::instance()->setSleepTimerDuration(m_sleepTimerSpinBox->value());
 
     this->accept();
 }
 
+void SettingsDialog::onMediaPlayerChanged(const QVariant &player) {
+    m_mediaPlayerCommandEdit->setEnabled(player.toString() == "other");
+}
+
 void SettingsDialog::showNetworkProxyDialog() {
     if (!m_proxyDialog) {
         m_proxyDialog = new NetworkProxyDialog(this);
