@@ -24,6 +24,7 @@ class QUrl;
 class Station;
 class QLabel;
 class ScrollArea;
+class LogoLabel;
 
 class StationInfoWindow : public StackedWindow
 {
@@ -40,6 +41,7 @@ private slots:
 
     void onTitleChanged(const QString &title);
     void onDescriptionChanged(const QString &description);
+    void onLogoChanged(const QUrl &logo);
     void onGenreChanged(const QString &genre);
     void onCountryChanged(const QString &country);
     void onLanguageChanged(const QString &language);
@@ -63,6 +65,8 @@ private:
     QLabel *m_sourceLabel;
     QLabel *m_lastPlayedLabel;
 
+    LogoLabel *m_logoLabel;
+
     ScrollArea *m_scrollArea;
 };
 
