@@ -95,6 +95,11 @@ void StationListWindow::searchStations(const QString &query) {
     m_model->searchStations(query);
 }
 
+void StationListWindow::showStations() {
+    this->setWindowTitle(tr("All stations"));
+    m_model->showStations();
+}
+
 void StationListWindow::showRecentlyPlayedStations() {
     this->setWindowTitle(tr("Recently played stations"));
     m_model->showRecentlyPlayedStations();
