@@ -104,14 +104,16 @@ void MediaPlayer::setState(MediaState::State state) {
 
 QString MediaPlayer::stateString() const {
     switch (this->state()) {
+    case MediaState::Stopped:
+        return tr("Stopped");
+    case MediaState::Loading:
+        return tr("Loading");
     case MediaState::Buffering:
         return tr("Buffering");
     case MediaState::Playing:
         return tr("Playing");
     case MediaState::Paused:
         return tr("Paused");
-    case MediaState::Stopped:
-        return tr("Stopped");
     case MediaState::Error:
         return tr("Error");
     default:
@@ -127,6 +129,20 @@ bool MediaPlayer::paused() const {
     return this->state() == MediaState::Paused;
 }
 
+bool MediaPlayer::stopped() const {
+    switch (this->state()) {
+    case MediaState::Stopped:
+    case MediaState::Error:
+        return true;
+    default:
+        return false;
+    }
+}
+
+bool MediaPlayer::loading() const {
+    return this->state() == MediaState::Loading;
+}
+
 bool MediaPlayer::buffering() const {
     return this->state() == MediaState::Buffering;
 }
@@ -231,16 +247,13 @@ void MediaPlayer::setTickInterval(int interval) {
 }
 
 void MediaPlayer::play() {
-    switch (this->state()) {
-    case MediaState::Error:
-        this->play(this->currentStation() ? this->currentStation()->source()
-                                          : m_mediaPlayer->media().canonicalUrl());
-        return;
-    default:
+    if ((m_mediaPlayer->media().isNull()) && (this->currentStation())) {
+        this->play(this->currentStation()->source());
+    }
+    else {
         m_mediaPlayer->setNetworkConfigurations(QList<QNetworkConfiguration>()
                                                 << NetworkAccessManager::instance()->activeConfiguration());
         m_mediaPlayer->play();
-        return;
     }
 }
 
@@ -255,6 +268,7 @@ void MediaPlayer::play(const QUrl &url) {
         this->setPlaybackMode(PlaybackMode::Radio);
 
         if (Utils::urlIsPlaylist(url)) {
+            this->setState(MediaState::Loading);
             m_extractor->getStreamUrl(url);
         }
         else {
@@ -334,6 +348,8 @@ void MediaPlayer::onStateChanged(QMediaPlayer::State state) {
 void MediaPlayer::onMediaStatusChanged(QMediaPlayer::MediaStatus status) {
     switch (status) {
     case QMediaPlayer::LoadingMedia:
+        this->setState(MediaState::Loading);
+        break;
     case QMediaPlayer::BufferingMedia:
         this->setState(MediaState::Buffering);
         break;
@@ -349,7 +365,29 @@ void MediaPlayer::onMediaError(QMediaPlayer::Error mediaError) {
     if (m_mediaPlayer->media().isNull()) {
         return;
     }
+#ifdef Q_OS_SYMBIAN
+    switch (mediaError) {
+    case QMediaPlayer::NoError:
+        return;
+    case QMediaPlayer::ResourceError:
+        m_mediaPlayer->setMedia(QMediaContent());
+        return;
+    case QMediaPlayer::FormatError:
+        this->setErrorString(tr("Format not supported"));
+        break;
+    case QMediaPlayer::NetworkError:
+        this->setErrorString(tr("Network error"));
+        break;
+    default:
+        this->setErrorString(m_mediaPlayer->errorString());
+        break;
+    }
 
+    m_mediaPlayer->setMedia(QMediaContent());
+    this->setState(MediaState::Error);
+    this->setSleepTimerEnabled(false);
+    emit error(this->errorString());
+#else
     switch (mediaError) {
     case QMediaPlayer::NoError:
         return;
@@ -367,9 +405,11 @@ void MediaPlayer::onMediaError(QMediaPlayer::Error mediaError) {
         break;
     }
 
+    m_mediaPlayer->setMedia(QMediaContent());
     this->setState(MediaState::Error);
     this->setSleepTimerEnabled(false);
     emit error(this->errorString());
+#endif
 }
 
 void MediaPlayer::onExtractorError(const QString &errorString) {
