@@ -44,6 +44,12 @@ class MediaPlayer : public QObject
     Q_PROPERTY(bool paused
                READ paused
                NOTIFY stateChanged)
+    Q_PROPERTY(bool stopped
+               READ stopped
+               NOTIFY stateChanged)
+    Q_PROPERTY(bool loading
+               READ loading
+               NOTIFY stateChanged)
     Q_PROPERTY(bool buffering
                READ buffering
                NOTIFY stateChanged)
@@ -114,6 +120,10 @@ public:
 
     bool paused() const;
 
+    bool stopped() const;
+
+    bool loading() const;
+
     bool buffering() const;
 
     bool seekable() const;
