@@ -25,16 +25,20 @@
 #include "../base/homescreenmodel.h"
 #include "../base/database.h"
 #include "../base/stationfilterlistmodel.h"
-#include "../base/pairlistmodel.h"
+#include "../base/podcastfilterlistmodel.h"
+#include "../base/podcastepisodefilterlistmodel.h"
 #include "../base/searchlistmodel.h"
 #include "../base/selectionmodels.h"
 #include "../base/settings.h"
 #include "../base/utils.h"
 #include "../base/logodownloader.h"
 #include "../base/streamextractor.h"
+#include "../base/podcast.h"
 #include "../tunein/tuneinhomescreenmodel.h"
 #include "../tunein/tuneinstationfilterlistmodel.h"
 #include "../tunein/tuneinpairlistmodel.h"
+#include "../tunein/tuneinpodcastfilterlistmodel.h"
+#include "../tunein/tuneinpodcastepisodefilterlistmodel.h"
 #include "../tunein/tuneinstation.h"
 #ifdef MOBILITY_PLAYER
 #include "../mediaplayer/mobility/mediaplayer.h"
@@ -58,22 +62,28 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
 
     qmlRegisterType<HomescreenModel>("com.cuteradio.models", 1, 0, "HomescreenModel");
     qmlRegisterType<StationFilterListModel>("com.cuteradio.models", 1, 0, "StationListModel");
-    qmlRegisterType<PairListModel>("com.cuteradio.models", 1, 0, "PairListModel");
+    qmlRegisterType<PodcastFilterListModel>("com.cuteradio.models", 1, 0, "PodcastListModel");
+    qmlRegisterType<PodcastEpisodeFilterListModel>("com.cuteradio.models", 1, 0, "PodcastEpisodeListModel");
     qmlRegisterType<TuneInHomescreenModel>("com.cuteradio.models", 1, 0, "TuneInHomescreenModel");
     qmlRegisterType<TuneInStationFilterListModel>("com.cuteradio.models", 1, 0, "TuneInStationListModel");
     qmlRegisterType<TuneInPairListModel>("com.cuteradio.models", 1, 0, "TuneInPairListModel");
+    qmlRegisterType<TuneInPodcastFilterListModel>("com.cuteradio.models", 1, 0, "TuneInPodcastListModel");
+    qmlRegisterType<TuneInPodcastEpisodeFilterListModel>("com.cuteradio.models", 1, 0, "TuneInPodcastEpisodeListModel");
     qmlRegisterType<ScreenOrientationModel>("com.cuteradio.models", 1, 0, "ScreenOrientationModel");
     qmlRegisterType<LanguageModel>("com.cuteradio.models", 1, 0, "LanguageModel");
     qmlRegisterType<MediaPlayerModel>("com.cuteradio.models", 1, 0, "MediaPlayerModel");
+    qmlRegisterType<StationTypeModel>("com.cuteradio.models", 1, 0, "StationTypeModel");
     qmlRegisterType<NetworkProxyTypeModel>("com.cuteradio.models", 1, 0, "NetworkProxyTypeModel");
     qmlRegisterType<Station>("com.cuteradio.items", 1, 0, "Station");
+    qmlRegisterType<Podcast>("com.cuteradio.items", 1, 0, "Podcast");
     qmlRegisterType<TuneInStation>("com.cuteradio.items", 1, 0, "TuneInStation");
     qmlRegisterType<LogoDownloader>("com.cuteradio.items", 1, 0, "LogoDownloader");
 
     qmlRegisterUncreatableType<ScreenOrientation>("com.cuteradio.enums", 1, 0, "ScreenOrientation", "Y U create enum?");
     qmlRegisterUncreatableType<Queries>("com.cuteradio.enums", 1, 0, "Queries", "Y U create enum?");
     qmlRegisterUncreatableType<PlaybackMode>("com.cuteradio.enums", 1, 0, "PlaybackMode", "Y U create enum?");
-    qmlRegisterUncreatableType<MediaState>("com.cuteradio.enums", 1, 0, "MediaState", "Y U create enum?");
+    qmlRegisterUncreatableType<Services>("com.cuteradio.enums", 1, 0, "Services", "Y U create enum?");
+    qmlRegisterUncreatableType<Stations>("com.cuteradio.enums", 1, 0, "Stations", "Y U create enum?");
 
     Settings settings;
     Database database;
