@@ -27,17 +27,17 @@
 <context>
     <name>AddPodcastDialog</name>
     <message>
-        <location filename="../../src/maemo5/addpodcastdialog.cpp" line="40"/>
+        <location filename="../../src/maemo5/addpodcastdialog.cpp" line="41"/>
         <source>Add podcast</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/addpodcastdialog.cpp" line="45"/>
+        <location filename="../../src/maemo5/addpodcastdialog.cpp" line="46"/>
         <source>Source</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/addpodcastdialog.cpp" line="116"/>
+        <location filename="../../src/maemo5/addpodcastdialog.cpp" line="124"/>
         <source>No podcast information found</source>
         <translation type="unfinished"></translation>
     </message>
@@ -45,171 +45,129 @@
 <context>
     <name>AddStationDialog</name>
     <message>
-        <location filename="../../src/maemo5/addstationdialog.cpp" line="41"/>
-        <location filename="../../src/maemo5/addstationdialog.cpp" line="91"/>
+        <location filename="../../src/maemo5/addstationdialog.cpp" line="42"/>
+        <location filename="../../src/maemo5/addstationdialog.cpp" line="94"/>
         <source>Favourite?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/addstationdialog.cpp" line="46"/>
+        <location filename="../../src/maemo5/addstationdialog.cpp" line="47"/>
         <source>Add station</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/addstationdialog.cpp" line="51"/>
-        <location filename="../../src/maemo5/addstationdialog.cpp" line="101"/>
+        <location filename="../../src/maemo5/addstationdialog.cpp" line="52"/>
+        <location filename="../../src/maemo5/addstationdialog.cpp" line="104"/>
         <source>Title</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/addstationdialog.cpp" line="53"/>
-        <location filename="../../src/maemo5/addstationdialog.cpp" line="103"/>
+        <location filename="../../src/maemo5/addstationdialog.cpp" line="54"/>
+        <location filename="../../src/maemo5/addstationdialog.cpp" line="106"/>
         <source>Description</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/addstationdialog.cpp" line="55"/>
-        <location filename="../../src/maemo5/addstationdialog.cpp" line="105"/>
+        <location filename="../../src/maemo5/addstationdialog.cpp" line="56"/>
+        <location filename="../../src/maemo5/addstationdialog.cpp" line="108"/>
         <source>Logo</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/addstationdialog.cpp" line="57"/>
-        <location filename="../../src/maemo5/addstationdialog.cpp" line="107"/>
+        <location filename="../../src/maemo5/addstationdialog.cpp" line="58"/>
+        <location filename="../../src/maemo5/addstationdialog.cpp" line="110"/>
         <source>Genre</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/addstationdialog.cpp" line="59"/>
-        <location filename="../../src/maemo5/addstationdialog.cpp" line="109"/>
+        <location filename="../../src/maemo5/addstationdialog.cpp" line="60"/>
+        <location filename="../../src/maemo5/addstationdialog.cpp" line="112"/>
         <source>Country</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/addstationdialog.cpp" line="61"/>
-        <location filename="../../src/maemo5/addstationdialog.cpp" line="111"/>
+        <location filename="../../src/maemo5/addstationdialog.cpp" line="62"/>
+        <location filename="../../src/maemo5/addstationdialog.cpp" line="114"/>
         <source>Language</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/addstationdialog.cpp" line="63"/>
-        <location filename="../../src/maemo5/addstationdialog.cpp" line="113"/>
+        <location filename="../../src/maemo5/addstationdialog.cpp" line="64"/>
+        <location filename="../../src/maemo5/addstationdialog.cpp" line="116"/>
         <source>Source</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/addstationdialog.cpp" line="96"/>
+        <location filename="../../src/maemo5/addstationdialog.cpp" line="99"/>
         <source>Edit station</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
-<context>
-    <name>BrowseListDelegate</name>
-    <message>
-        <location filename="../../src/maemo5/browselistdelegate.cpp" line="52"/>
-        <source>%1 stations</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
-<context>
-    <name>BrowseListWindow</name>
-    <message>
-        <location filename="../../src/maemo5/browselistwindow.cpp" line="74"/>
-        <source>Stations by genre</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../src/maemo5/browselistwindow.cpp" line="75"/>
-        <source>No genres found</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../src/maemo5/browselistwindow.cpp" line="80"/>
-        <source>Stations by country</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../src/maemo5/browselistwindow.cpp" line="81"/>
-        <source>No countries found</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../src/maemo5/browselistwindow.cpp" line="86"/>
-        <source>Stations by language</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../src/maemo5/browselistwindow.cpp" line="87"/>
-        <source>No languages found</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
 <context>
     <name>Database</name>
     <message>
-        <location filename="../../src/base/database.cpp" line="118"/>
+        <location filename="../../src/base/database.cpp" line="111"/>
         <source>New station</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/base/database.cpp" line="118"/>
-        <location filename="../../src/base/database.cpp" line="965"/>
+        <location filename="../../src/base/database.cpp" line="111"/>
+        <location filename="../../src/base/database.cpp" line="572"/>
         <source>added</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/base/database.cpp" line="123"/>
-        <location filename="../../src/base/database.cpp" line="970"/>
+        <location filename="../../src/base/database.cpp" line="116"/>
+        <location filename="../../src/base/database.cpp" line="577"/>
         <source>Cannot add new station</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/base/database.cpp" line="185"/>
-        <location filename="../../src/base/database.cpp" line="244"/>
+        <location filename="../../src/base/database.cpp" line="143"/>
+        <location filename="../../src/base/database.cpp" line="170"/>
         <source>Station updated</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/base/database.cpp" line="192"/>
-        <location filename="../../src/base/database.cpp" line="251"/>
+        <location filename="../../src/base/database.cpp" line="150"/>
+        <location filename="../../src/base/database.cpp" line="177"/>
         <source>Cannot update station</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/base/database.cpp" line="289"/>
+        <location filename="../../src/base/database.cpp" line="194"/>
         <source>Station deleted</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/base/database.cpp" line="294"/>
-        <location filename="../../src/base/database.cpp" line="299"/>
+        <location filename="../../src/base/database.cpp" line="199"/>
         <source>Cannot delete station</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/base/database.cpp" line="965"/>
+        <location filename="../../src/base/database.cpp" line="572"/>
         <source>New podcast</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/base/database.cpp" line="997"/>
-        <location filename="../../src/base/database.cpp" line="1024"/>
+        <location filename="../../src/base/database.cpp" line="604"/>
+        <location filename="../../src/base/database.cpp" line="631"/>
         <source>Podcast updated</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/base/database.cpp" line="1004"/>
-        <location filename="../../src/base/database.cpp" line="1031"/>
+        <location filename="../../src/base/database.cpp" line="611"/>
+        <location filename="../../src/base/database.cpp" line="638"/>
         <source>Cannot update podcast</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/base/database.cpp" line="1048"/>
+        <location filename="../../src/base/database.cpp" line="655"/>
         <source>Podcast deleted</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/base/database.cpp" line="1053"/>
+        <location filename="../../src/base/database.cpp" line="660"/>
         <source>Cannot delete podcast</source>
         <translation type="unfinished"></translation>
     </message>
@@ -217,27 +175,27 @@
 <context>
     <name>EditPodcastDialog</name>
     <message>
-        <location filename="../../src/maemo5/editpodcastdialog.cpp" line="41"/>
+        <location filename="../../src/maemo5/editpodcastdialog.cpp" line="42"/>
         <source>Edit podcast</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/editpodcastdialog.cpp" line="46"/>
+        <location filename="../../src/maemo5/editpodcastdialog.cpp" line="47"/>
         <source>Title</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/editpodcastdialog.cpp" line="48"/>
+        <location filename="../../src/maemo5/editpodcastdialog.cpp" line="49"/>
         <source>Description</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/editpodcastdialog.cpp" line="50"/>
+        <location filename="../../src/maemo5/editpodcastdialog.cpp" line="51"/>
         <source>Logo</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/editpodcastdialog.cpp" line="52"/>
+        <location filename="../../src/maemo5/editpodcastdialog.cpp" line="53"/>
         <source>Source</source>
         <translation type="unfinished"></translation>
     </message>
@@ -246,37 +204,27 @@
     <name>HomescreenModel</name>
     <message>
         <location filename="../../src/base/homescreenmodel.cpp" line="22"/>
-        <source>Stations by genre</source>
+        <source>All stations</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../../src/base/homescreenmodel.cpp" line="23"/>
-        <source>Stations by country</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../src/base/homescreenmodel.cpp" line="24"/>
-        <source>Stations by language</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../src/base/homescreenmodel.cpp" line="25"/>
         <source>Recently played stations</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/base/homescreenmodel.cpp" line="26"/>
+        <location filename="../../src/base/homescreenmodel.cpp" line="24"/>
         <source>Favourite stations</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/base/homescreenmodel.cpp" line="28"/>
-        <location filename="../../src/base/homescreenmodel.cpp" line="31"/>
+        <location filename="../../src/base/homescreenmodel.cpp" line="26"/>
+        <location filename="../../src/base/homescreenmodel.cpp" line="29"/>
         <source>Podcasts</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/base/homescreenmodel.cpp" line="29"/>
+        <location filename="../../src/base/homescreenmodel.cpp" line="27"/>
         <source>TuneIn</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1207,52 +1155,52 @@
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../../src/maemo5/mainwindow.cpp" line="55"/>
+        <location filename="../../src/maemo5/mainwindow.cpp" line="54"/>
         <source>Search for</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/mainwindow.cpp" line="60"/>
+        <location filename="../../src/maemo5/mainwindow.cpp" line="59"/>
         <source>cuteRadio</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/mainwindow.cpp" line="62"/>
+        <location filename="../../src/maemo5/mainwindow.cpp" line="61"/>
         <source>Play from URL</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/mainwindow.cpp" line="63"/>
+        <location filename="../../src/maemo5/mainwindow.cpp" line="62"/>
         <source>Add station</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/mainwindow.cpp" line="64"/>
+        <location filename="../../src/maemo5/mainwindow.cpp" line="63"/>
         <source>Add podcast</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/mainwindow.cpp" line="65"/>
+        <location filename="../../src/maemo5/mainwindow.cpp" line="64"/>
         <source>Settings</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/mainwindow.cpp" line="66"/>
+        <location filename="../../src/maemo5/mainwindow.cpp" line="65"/>
         <source>About</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/mainwindow.cpp" line="69"/>
+        <location filename="../../src/maemo5/mainwindow.cpp" line="68"/>
         <source>Search</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/mainwindow.cpp" line="236"/>
+        <location filename="../../src/maemo5/mainwindow.cpp" line="217"/>
         <source>Please wait</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/mainwindow.cpp" line="237"/>
+        <location filename="../../src/maemo5/mainwindow.cpp" line="218"/>
         <source>Cancel</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1260,47 +1208,54 @@
 <context>
     <name>MediaPlayer</name>
     <message>
-        <location filename="../../src/mediaplayer/mobility/mediaplayer.cpp" line="108"/>
+        <location filename="../../src/mediaplayer/mobility/mediaplayer.cpp" line="112"/>
         <source>Buffering</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/mediaplayer/mobility/mediaplayer.cpp" line="110"/>
+        <location filename="../../src/mediaplayer/mobility/mediaplayer.cpp" line="114"/>
         <source>Playing</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/mediaplayer/mobility/mediaplayer.cpp" line="112"/>
+        <location filename="../../src/mediaplayer/mobility/mediaplayer.cpp" line="116"/>
         <source>Paused</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/mediaplayer/mobility/mediaplayer.cpp" line="114"/>
+        <location filename="../../src/mediaplayer/mobility/mediaplayer.cpp" line="108"/>
         <source>Stopped</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/mediaplayer/mobility/mediaplayer.cpp" line="116"/>
-        <source>Error</source>
+        <location filename="../../src/mediaplayer/mobility/mediaplayer.cpp" line="110"/>
+        <source>Loading</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../../src/mediaplayer/mobility/mediaplayer.cpp" line="118"/>
+        <source>Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../src/mediaplayer/mobility/mediaplayer.cpp" line="120"/>
         <source>Unknown</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/mediaplayer/mobility/mediaplayer.cpp" line="357"/>
+        <location filename="../../src/mediaplayer/mobility/mediaplayer.cpp" line="395"/>
         <source>Cannot find media resource</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/mediaplayer/mobility/mediaplayer.cpp" line="360"/>
+        <location filename="../../src/mediaplayer/mobility/mediaplayer.cpp" line="376"/>
+        <location filename="../../src/mediaplayer/mobility/mediaplayer.cpp" line="398"/>
         <source>Format not supported</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/mediaplayer/mobility/mediaplayer.cpp" line="363"/>
+        <location filename="../../src/mediaplayer/mobility/mediaplayer.cpp" line="379"/>
+        <location filename="../../src/mediaplayer/mobility/mediaplayer.cpp" line="401"/>
         <source>Network error</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1377,39 +1332,39 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/nowplayingwindow.cpp" line="199"/>
+        <location filename="../../src/maemo5/nowplayingwindow.cpp" line="204"/>
         <source>Title</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/nowplayingwindow.cpp" line="200"/>
+        <location filename="../../src/maemo5/nowplayingwindow.cpp" line="205"/>
         <source>Artist</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/nowplayingwindow.cpp" line="200"/>
-        <location filename="../../src/maemo5/nowplayingwindow.cpp" line="201"/>
-        <location filename="../../src/maemo5/nowplayingwindow.cpp" line="203"/>
+        <location filename="../../src/maemo5/nowplayingwindow.cpp" line="205"/>
+        <location filename="../../src/maemo5/nowplayingwindow.cpp" line="206"/>
+        <location filename="../../src/maemo5/nowplayingwindow.cpp" line="208"/>
         <source>Unknown</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/nowplayingwindow.cpp" line="201"/>
+        <location filename="../../src/maemo5/nowplayingwindow.cpp" line="206"/>
         <source>Album</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/nowplayingwindow.cpp" line="202"/>
+        <location filename="../../src/maemo5/nowplayingwindow.cpp" line="207"/>
         <source>Genre</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/nowplayingwindow.cpp" line="203"/>
+        <location filename="../../src/maemo5/nowplayingwindow.cpp" line="208"/>
         <source>Bitrate</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/nowplayingwindow.cpp" line="208"/>
+        <location filename="../../src/maemo5/nowplayingwindow.cpp" line="213"/>
         <source>Status</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1417,12 +1372,12 @@
 <context>
     <name>PlayStationDialog</name>
     <message>
-        <location filename="../../src/maemo5/playstationdialog.cpp" line="38"/>
-        <source>Play station</source>
+        <location filename="../../src/maemo5/playstationdialog.cpp" line="39"/>
+        <source>Play from URL</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/playstationdialog.cpp" line="43"/>
+        <location filename="../../src/maemo5/playstationdialog.cpp" line="44"/>
         <source>Source</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1725,7 +1680,7 @@
     </message>
     <message>
         <location filename="../../src/maemo5/stationlistwindow.cpp" line="50"/>
-        <location filename="../../src/maemo5/stationlistwindow.cpp" line="147"/>
+        <location filename="../../src/maemo5/stationlistwindow.cpp" line="152"/>
         <source>Add to favourites</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1756,26 +1711,31 @@
     </message>
     <message>
         <location filename="../../src/maemo5/stationlistwindow.cpp" line="99"/>
-        <source>Recently played stations</source>
+        <source>All stations</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../../src/maemo5/stationlistwindow.cpp" line="104"/>
+        <source>Recently played stations</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../src/maemo5/stationlistwindow.cpp" line="109"/>
         <source>Favourite stations</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/stationlistwindow.cpp" line="147"/>
+        <location filename="../../src/maemo5/stationlistwindow.cpp" line="152"/>
         <source>Delete from favourites</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/stationlistwindow.cpp" line="173"/>
+        <location filename="../../src/maemo5/stationlistwindow.cpp" line="178"/>
         <source>Delete station?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/stationlistwindow.cpp" line="173"/>
+        <location filename="../../src/maemo5/stationlistwindow.cpp" line="178"/>
         <source>Do you wish to delete the station &apos;%1&apos; from the database?</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1816,22 +1776,22 @@
 <context>
     <name>TuneInAddPodcastDialog</name>
     <message>
-        <location filename="../../src/maemo5/tuneinaddpodcastdialog.cpp" line="41"/>
+        <location filename="../../src/maemo5/tuneinaddpodcastdialog.cpp" line="42"/>
         <source>Add podcast</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/tuneinaddpodcastdialog.cpp" line="46"/>
+        <location filename="../../src/maemo5/tuneinaddpodcastdialog.cpp" line="47"/>
         <source>Title</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/tuneinaddpodcastdialog.cpp" line="48"/>
+        <location filename="../../src/maemo5/tuneinaddpodcastdialog.cpp" line="49"/>
         <source>Description</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/tuneinaddpodcastdialog.cpp" line="50"/>
+        <location filename="../../src/maemo5/tuneinaddpodcastdialog.cpp" line="51"/>
         <source>Source</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1839,47 +1799,47 @@
 <context>
     <name>TuneInAddStationDialog</name>
     <message>
-        <location filename="../../src/maemo5/tuneinaddstationdialog.cpp" line="43"/>
+        <location filename="../../src/maemo5/tuneinaddstationdialog.cpp" line="44"/>
         <source>Favourite?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/tuneinaddstationdialog.cpp" line="48"/>
+        <location filename="../../src/maemo5/tuneinaddstationdialog.cpp" line="49"/>
         <source>Add station</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/tuneinaddstationdialog.cpp" line="53"/>
+        <location filename="../../src/maemo5/tuneinaddstationdialog.cpp" line="54"/>
         <source>Title</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/tuneinaddstationdialog.cpp" line="55"/>
+        <location filename="../../src/maemo5/tuneinaddstationdialog.cpp" line="56"/>
         <source>Description</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/tuneinaddstationdialog.cpp" line="57"/>
+        <location filename="../../src/maemo5/tuneinaddstationdialog.cpp" line="58"/>
         <source>Genre</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/tuneinaddstationdialog.cpp" line="59"/>
+        <location filename="../../src/maemo5/tuneinaddstationdialog.cpp" line="60"/>
         <source>Country</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/tuneinaddstationdialog.cpp" line="61"/>
+        <location filename="../../src/maemo5/tuneinaddstationdialog.cpp" line="62"/>
         <source>Language</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/tuneinaddstationdialog.cpp" line="63"/>
+        <location filename="../../src/maemo5/tuneinaddstationdialog.cpp" line="64"/>
         <source>Source</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/tuneinaddstationdialog.cpp" line="131"/>
+        <location filename="../../src/maemo5/tuneinaddstationdialog.cpp" line="140"/>
         <source>No station information found</source>
         <translation type="unfinished"></translation>
     </message>
